package ca.nrc.naryrelations;

import static org.apache.uima.fit.factory.AnalysisEngineFactory.createEngine;
import static org.apache.uima.fit.factory.CollectionReaderFactory.createReader;
import static org.apache.uima.fit.util.JCasUtil.select;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.apache.uima.analysis_engine.AnalysisEngine;
import org.apache.uima.collection.CollectionReader;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.jcas.JCas;
import org.dkpro.core.io.brat.BratReader;
import org.dkpro.core.io.xmi.XmiWriter;

import ca.nrc.t2rels.freetext.annotations.CasualtiesRelationNary;

public class Example
{
    public static void main(String[] args) throws Exception
    {
        List<JCas> documents = new ArrayList<>();

        CollectionReader reader = createReader(BratReader.class, 
                BratReader.PARAM_SOURCE_LOCATION, "src/main/resources/testfiles/west-nile.ann",
                BratReader.PARAM_MAPPING, FileUtils.readFileToString(
                        new File("src/main/resources/testfiles/mapping.json"), "UTF-8"));

        while (reader.hasNext()) {
            JCas document = JCasFactory.createJCas();
            reader.getNext(document.getCas());
            documents.add(document);
        }
        
        reader.close();
        reader.destroy();
        
        AnalysisEngine writer = createEngine(XmiWriter.class,
            XmiWriter.PARAM_TARGET_LOCATION, "target/out",
            XmiWriter.PARAM_OVERWRITE, true);
        
        for (JCas document : documents) {
            writer.process(document);
        }
        
        writer.collectionProcessComplete();
        writer.destroy();
        
        for (JCas document : documents) {
            for (CasualtiesRelationNary casualties : select(document, CasualtiesRelationNary.class)) {
                System.out.println(casualties);   
            }
        }
    }
}
